ISSA- STRENGTH &CONDITIONING
EXAM Q’S AND A’S
Q: What is the neural circuitry that travels outside the spinal cord? - -
Peripheral nervous system (the correct answer)
-Q: Which of the following is a sensory receptor within a muscle that detects
changes in length and helps regulate contraction? - -Muscle spindle (the
correct answer)
-Q: Which of the following are branches of the cell body that act as
receivers, collecting information from other neurons? - -Dendrites (the
correct answer)
-Q: A cascade of events, resulting in muscle contraction, is triggered when
which of the following chemical neurotransmitters binds to receptors on the
muscle? - -Acetylcholine (the correct answer)
-Q: Which division of the peripheral nervous system controls voluntary
movement? - -Somatic nervous system (the correct answer)
-Q: Which type of motor unit can contract for many hours, or even days if
necessary? - -Slow (S) of Motor Unit (the correct answer)
-Q: Which type of motor unit has a large motor neuron and consists of a
large bundle of type IIx muscle fibers? - -Fast fatigable (FF) (the correct
answer)
-Q: Voluntary movement starts in the - -cerebral cortex. (the correct
answer)
-Q: Which of the following is the process that allows a muscle spindle to
contract at the same rate as the muscle where it resides? - -Alpha-gamma
co-activation (the correct answer)
-Q: How many nerves are contained within the peripheral nervous system,
which includes all the neurons and glia outside of the brain and spinal cord? -
-43 pairs (the correct answer)
-Q: The muscular system includes how many muscles? - -Approximately 650
(the correct answer)
-Q: Which muscle fiber type are the largest, and produce the most amount
of force? - -Type IIx (the correct answer)
, -Q: The cross-bridge cycle requires energy, which is provided by - -ATP
hydrolysis. (the correct answer)
-Q: The function of epimysium is to - -protect muscle from friction against
other muscles or bone. (the correct answer)
-Q: With regard to mitochondrial density, which muscle fiber type has a very
small amount of mitochondria? - -Type IIx (the correct answer)
-Q: Regarding the make-up of a person's muscle fiber ratio, which of the
following is correct? - -It can't be changed to a large degree (the correct
answer)
-Q: It is currently theorized that training with heavy loads causes - -equal
growth of type I and type II fibers. (the correct answer)
-Q: Which of the following functions like girdles and guy wires to provide an
interconnected structure? - -Fascia (the correct answer)
-Q: Current research demonstrates what three possible mechanisms for
inducing hypertrophy? - -Mechanical tension, metabolic stress, muscle
damage (the correct answer)
-Q: The functional units that can make a muscle shorten are: - -Sarcomeres
(the correct answer)
-Q: Which of the following is found within the appendicular skeleton? - -
Bones of the upper and lower extremities (the correct answer)
-Q: Movement between two adjacent vertebrae is made possible by - -facet
joints. (the correct answer)
-Q: Wolff's Law describes the way - -the body responds by increasing or
decreasing the bone's diameter (the correct answer)
-Q: In addition to being a barrier to pain, what important role does cartilage
play? - -Bone development (the correct answer)
-Q: Which of the following are mature bone cells that maintain a bone's
matrix? - -Osteocytes (the correct answer)
-Q: Bone-on-bone contact that results in joint pain and stiffness from a loss
of articular cartilage is - -osteoarthritis. (the correct answer)
, -Q: Elastin, an important elastic protein found in all connective tissues,
allows those tissues to - -regain their original shape after being stretched.
(the correct answer)
-Q: Which of the following terms refers to the main part or the shaft of a
long bone? - -Diaphysis (the correct answer)
-Q: The frontal plane is an imaginary plane that divides the body into which
of the following segments? - -Anterior and posterior (the correct answer)
-Q: The angle that a joint rotates around its axis is referred to as - -the
direction of rotation (the correct answer)
-Q: What term describes the smallest blood vessels in the human body? - -
Capillaries (the correct answer)
-Q: What has been found to truly help create more muscular support when
performing an intense exercise or lift? - -Bracing effect of a tight core (the
correct answer)
-Q: Which of the following is the largest lymphatic organ in the human body?
- -Spleen (the correct answer)
-Q: Which of the following is one of the three main functions of the
respiratory system? - -Removal of waste products of metabolism (the correct
answer)
-Q: The normal amount of air displaced between inhalation and exhalation
when no additional force is applied, is known as - -tidal volume. (the correct
answer)
-Q: The major glands of the endocrine system include the - -hypothalamus.
(the correct answer)
-Q: The amount of blood pumped through the heart per minute is known as
which of the following? - -Cardiac output (the correct answer)
-Q: Peripheral resistance is defined as - -the amount of resistance to blood
flow in the arteries. (the correct answer)
-Q: Plasma makes up about what percentage of blood volume? - -55% (the
correct answer)
-Q: The right atrium receives deoxygenated blood from the body and moves
it into the - -right ventricle. (the correct answer)
EXAM Q’S AND A’S
Q: What is the neural circuitry that travels outside the spinal cord? - -
Peripheral nervous system (the correct answer)
-Q: Which of the following is a sensory receptor within a muscle that detects
changes in length and helps regulate contraction? - -Muscle spindle (the
correct answer)
-Q: Which of the following are branches of the cell body that act as
receivers, collecting information from other neurons? - -Dendrites (the
correct answer)
-Q: A cascade of events, resulting in muscle contraction, is triggered when
which of the following chemical neurotransmitters binds to receptors on the
muscle? - -Acetylcholine (the correct answer)
-Q: Which division of the peripheral nervous system controls voluntary
movement? - -Somatic nervous system (the correct answer)
-Q: Which type of motor unit can contract for many hours, or even days if
necessary? - -Slow (S) of Motor Unit (the correct answer)
-Q: Which type of motor unit has a large motor neuron and consists of a
large bundle of type IIx muscle fibers? - -Fast fatigable (FF) (the correct
answer)
-Q: Voluntary movement starts in the - -cerebral cortex. (the correct
answer)
-Q: Which of the following is the process that allows a muscle spindle to
contract at the same rate as the muscle where it resides? - -Alpha-gamma
co-activation (the correct answer)
-Q: How many nerves are contained within the peripheral nervous system,
which includes all the neurons and glia outside of the brain and spinal cord? -
-43 pairs (the correct answer)
-Q: The muscular system includes how many muscles? - -Approximately 650
(the correct answer)
-Q: Which muscle fiber type are the largest, and produce the most amount
of force? - -Type IIx (the correct answer)
, -Q: The cross-bridge cycle requires energy, which is provided by - -ATP
hydrolysis. (the correct answer)
-Q: The function of epimysium is to - -protect muscle from friction against
other muscles or bone. (the correct answer)
-Q: With regard to mitochondrial density, which muscle fiber type has a very
small amount of mitochondria? - -Type IIx (the correct answer)
-Q: Regarding the make-up of a person's muscle fiber ratio, which of the
following is correct? - -It can't be changed to a large degree (the correct
answer)
-Q: It is currently theorized that training with heavy loads causes - -equal
growth of type I and type II fibers. (the correct answer)
-Q: Which of the following functions like girdles and guy wires to provide an
interconnected structure? - -Fascia (the correct answer)
-Q: Current research demonstrates what three possible mechanisms for
inducing hypertrophy? - -Mechanical tension, metabolic stress, muscle
damage (the correct answer)
-Q: The functional units that can make a muscle shorten are: - -Sarcomeres
(the correct answer)
-Q: Which of the following is found within the appendicular skeleton? - -
Bones of the upper and lower extremities (the correct answer)
-Q: Movement between two adjacent vertebrae is made possible by - -facet
joints. (the correct answer)
-Q: Wolff's Law describes the way - -the body responds by increasing or
decreasing the bone's diameter (the correct answer)
-Q: In addition to being a barrier to pain, what important role does cartilage
play? - -Bone development (the correct answer)
-Q: Which of the following are mature bone cells that maintain a bone's
matrix? - -Osteocytes (the correct answer)
-Q: Bone-on-bone contact that results in joint pain and stiffness from a loss
of articular cartilage is - -osteoarthritis. (the correct answer)
, -Q: Elastin, an important elastic protein found in all connective tissues,
allows those tissues to - -regain their original shape after being stretched.
(the correct answer)
-Q: Which of the following terms refers to the main part or the shaft of a
long bone? - -Diaphysis (the correct answer)
-Q: The frontal plane is an imaginary plane that divides the body into which
of the following segments? - -Anterior and posterior (the correct answer)
-Q: The angle that a joint rotates around its axis is referred to as - -the
direction of rotation (the correct answer)
-Q: What term describes the smallest blood vessels in the human body? - -
Capillaries (the correct answer)
-Q: What has been found to truly help create more muscular support when
performing an intense exercise or lift? - -Bracing effect of a tight core (the
correct answer)
-Q: Which of the following is the largest lymphatic organ in the human body?
- -Spleen (the correct answer)
-Q: Which of the following is one of the three main functions of the
respiratory system? - -Removal of waste products of metabolism (the correct
answer)
-Q: The normal amount of air displaced between inhalation and exhalation
when no additional force is applied, is known as - -tidal volume. (the correct
answer)
-Q: The major glands of the endocrine system include the - -hypothalamus.
(the correct answer)
-Q: The amount of blood pumped through the heart per minute is known as
which of the following? - -Cardiac output (the correct answer)
-Q: Peripheral resistance is defined as - -the amount of resistance to blood
flow in the arteries. (the correct answer)
-Q: Plasma makes up about what percentage of blood volume? - -55% (the
correct answer)
-Q: The right atrium receives deoxygenated blood from the body and moves
it into the - -right ventricle. (the correct answer)